==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/realm/entity/MapWebAuthnPolicyEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapWebAuthnPolicyEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity> entityFieldDelegate;
    public MapWebAuthnPolicyEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public String getRpEntityName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.RP_ENTITY_NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setRpEntityName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.RP_ENTITY_NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.List<String> getSignatureAlgorithms() {
        return (java.util.List<String>) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.SIGNATURE_ALGORITHMS);
    }
    @SuppressWarnings("unchecked") @Override public void setSignatureAlgorithms(java.util.List<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.SIGNATURE_ALGORITHMS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRpId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.RP_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRpId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.RP_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAttestationConveyancePreference() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.ATTESTATION_CONVEYANCE_PREFERENCE);
    }
    @SuppressWarnings("unchecked") @Override public void setAttestationConveyancePreference(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.ATTESTATION_CONVEYANCE_PREFERENCE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthenticatorAttachment() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.AUTHENTICATOR_ATTACHMENT);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthenticatorAttachment(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.AUTHENTICATOR_ATTACHMENT, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRequireResidentKey() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.REQUIRE_RESIDENT_KEY);
    }
    @SuppressWarnings("unchecked") @Override public void setRequireResidentKey(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.REQUIRE_RESIDENT_KEY, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getUserVerificationRequirement() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.USER_VERIFICATION_REQUIREMENT);
    }
    @SuppressWarnings("unchecked") @Override public void setUserVerificationRequirement(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.USER_VERIFICATION_REQUIREMENT, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getCreateTimeout() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.CREATE_TIMEOUT);
    }
    @SuppressWarnings("unchecked") @Override public void setCreateTimeout(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.CREATE_TIMEOUT, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isAvoidSameAuthenticatorRegister() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.AVOID_SAME_AUTHENTICATOR_REGISTER);
    }
    @SuppressWarnings("unchecked") @Override public void setAvoidSameAuthenticatorRegister(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.AVOID_SAME_AUTHENTICATOR_REGISTER, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.List<String> getAcceptableAaguids() {
        return (java.util.List<String>) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.ACCEPTABLE_AAGUIDS);
    }
    @SuppressWarnings("unchecked") @Override public void setAcceptableAaguids(java.util.List<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.ACCEPTABLE_AAGUIDS, p0);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapWebAuthnPolicyEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapWebAuthnPolicyEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity> entityFieldDelegate;
    public MapWebAuthnPolicyEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getRpEntityName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.RP_ENTITY_NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setRpEntityName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.RP_ENTITY_NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.List<String> getSignatureAlgorithms() {
        return (java.util.List<String>) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.SIGNATURE_ALGORITHMS);
    }
    @SuppressWarnings("unchecked") @Override public void setSignatureAlgorithms(java.util.List<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.SIGNATURE_ALGORITHMS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRpId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.RP_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRpId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.RP_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAttestationConveyancePreference() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.ATTESTATION_CONVEYANCE_PREFERENCE);
    }
    @SuppressWarnings("unchecked") @Override public void setAttestationConveyancePreference(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.ATTESTATION_CONVEYANCE_PREFERENCE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthenticatorAttachment() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.AUTHENTICATOR_ATTACHMENT);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthenticatorAttachment(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.AUTHENTICATOR_ATTACHMENT, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRequireResidentKey() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.REQUIRE_RESIDENT_KEY);
    }
    @SuppressWarnings("unchecked") @Override public void setRequireResidentKey(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.REQUIRE_RESIDENT_KEY, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getUserVerificationRequirement() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.USER_VERIFICATION_REQUIREMENT);
    }
    @SuppressWarnings("unchecked") @Override public void setUserVerificationRequirement(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.USER_VERIFICATION_REQUIREMENT, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getCreateTimeout() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.CREATE_TIMEOUT);
    }
    @SuppressWarnings("unchecked") @Override public void setCreateTimeout(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.CREATE_TIMEOUT, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isAvoidSameAuthenticatorRegister() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.AVOID_SAME_AUTHENTICATOR_REGISTER);
    }
    @SuppressWarnings("unchecked") @Override public void setAvoidSameAuthenticatorRegister(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.AVOID_SAME_AUTHENTICATOR_REGISTER, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.List<String> getAcceptableAaguids() {
        return (java.util.List<String>) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.ACCEPTABLE_AAGUIDS);
    }
    @SuppressWarnings("unchecked") @Override public void setAcceptableAaguids(java.util.List<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntityFields.ACCEPTABLE_AAGUIDS, p0);
    }
}
